#[repr(i16)]pub enum EmoteFetchType {
All = 0,
Custom = 1,
Platform = 2,
}Expand description
Types of emotes to fetch
Variants
All = 0
Get platform-level emoticons and custom emoticons corresponding to channel IDs
Custom = 1
Get the custom emoji corresponding to the channel IDs
Platform = 2
Get platform-level emoticons.